@@ -25,6 +25,7 @@
 #include "listdialog.h"
 #include "system.h"
 #include "optimizer.h"
+#include "scaddialog.h"
 #include "undocommands.h"
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -111,8 +112,10 @@ MainWindow::MainWindow(QWidget *parent) :
     /* fill speaker combos */
     ui->vendorComboBox->addItems(SpeakerDb::getVendors());
     ui->vendorComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);
+    ui->vendorComboBox->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     ui->modelComboBox->addItems(SpeakerDb::getModelsByVendor(ui->vendorComboBox->currentText()));
     ui->modelComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);
+    ui->modelComboBox->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
     /* undo history is empty */
     this->ui->actionUndo->setEnabled(false);
@@ -211,7 +214,7 @@ void MainWindow::onProjectImport()
     if (!projectSaved) {
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Project not saved"),
-                                      tr("The current project has not been saved. Continue anyway?"),
+                                      tr("Current project has not been saved. Continue anyway?"),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::No)
             return;
@@ -231,6 +234,15 @@ void MainWindow::onProjectImport()
 
 void MainWindow::onOpenRecentActionTriggered()
 {
+    if (!projectSaved) {
+        QMessageBox::StandardButton pressed =
+                QMessageBox::question(this, tr("Project not saved"),
+                                      tr("Current project has not been saved. Continue anyway?"),
+                                      QMessageBox::Yes|QMessageBox::No);
+        if (pressed == QMessageBox::No)
+            return;
+    }
+
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
         if (!loadFile(action->data().toString())) {
@@ -320,8 +332,10 @@ bool MainWindow::loadFile(const QString& fileName)
 
     ui->tabWidget->setCurrentIndex(currentTabIndex);
 
+    /*
     if (notInDbSpeaker)
         onSpeakerModify();
+    */
 
     projectSaved = true;
     return true;
@@ -437,7 +451,8 @@ void MainWindow::syncUiFromCurrentPortedBox(const PortedBox& box)
 {
     unlinkTabs();
     ui->portedVolumeDoubleSpinBox->setValue(box.getBoxVolume());
-    ui->portedResonancedoubleSpinBox->setValue(box.getResFreq());
+    ui->portedResonanceDoubleSpinBox->setValue(box.getResFreq());
+    ui->portedQualityLossFactorSpinBox->setValue(box.getLossQualityFactor());
     ui->portedPortsNumberSpinBox->setValue(box.getPortNum());
     ui->portedPortDiameterDoubleSpinBox->setValue(box.getPortDiam());
     bool slotPortActivated = box.getSlotPortActivated();
@@ -467,6 +482,7 @@ void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
     ui->bandPassSealedVolumeDoubleSpinBox->setValue(box.getSealedBoxVolume());
     ui->bandPassPortedVolumeDoubleSpinBox->setValue(box.getPortedBoxVolume());
     ui->bandPassPortedResonanceDoubleSpinBox->setValue(box.getPortedBoxResFreq());
+    ui->bandPassQualityLossFactorSpinBox->setValue(box.getLossQualityFactor());
     ui->bandPassPortsNumberSpinBox->setValue(box.getPortedBoxPortNum());
     ui->bandPassPortDiameterDoubleSpinBox->setValue(box.getPortedBoxPortDiam());
     bool slotPortActivated = box.getPortedBoxSlotPortActivated();
@@ -601,7 +617,7 @@ void MainWindow::onCurvePlot()
 {
     QString home = getHome();
     QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-    QString f = QString("QSpeakers %1 %2").arg(currentSpeaker.getModel()).arg(box);
+    QString f = QString("QSpeakers %1 %2 %3").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
     f.replace(' ', '_');
     QString fileName = QFileDialog::getSaveFileName(this, tr("Export for Gnuplot"), home + QDir::separator() + f + ".dat", tr("Gnuplot data (*.dat)"));
 
@@ -614,9 +630,19 @@ void MainWindow::onCurvePlot()
 
 void MainWindow::on3DScadExport()
 {
+    bool ok = false;
+    QList<qreal> vals = ScadDialog::getValues(2, this, &ok);
+    if (!ok)
+        return;
+
+    Q_ASSERT(vals.size() == 2);
+
+    qreal margin = vals.at(0); /* loudspeaker margin */
+    qreal thick = vals.at(1); /* wood thick */
+
     QString home = getHome();
     QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-    QString f = QString("QSpeakers %1 %2 3D").arg(currentSpeaker.getModel()).arg(box);
+    QString f = QString("QSpeakers %1 %2 %3 3D").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
     f.replace(' ', '_');
     QString fileName = QFileDialog::getSaveFileName(this, tr("Export for 3D OpenSCAD"), home + QDir::separator() + f + ".scad", tr("OpenSCAD script (*.scad)"));
 
@@ -624,14 +650,25 @@ void MainWindow::on3DScadExport()
     if (fileName.isEmpty())
         return;
 
-    exportScad3D(fileName, currentTabIndex);
+    exportScad3D(fileName, currentTabIndex, margin, thick);
 }
 
 void MainWindow::on2DScadExport()
 {
+    bool ok = false;
+    QList<qreal> vals = ScadDialog::getValues(3, this, &ok);
+    if (!ok)
+        return;
+
+    Q_ASSERT(vals.size() == 3);
+
+    qreal margin = vals.at(0); /* loudspeaker margin */
+    qreal thick = vals.at(1); /* wood thick */
+    qreal saw = vals.at(2); /* saw thick */
+
    QString home = getHome();
    QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-   QString f = QString("QSpeakers %1 %2 2D").arg(currentSpeaker.getModel()).arg(box);
+   QString f = QString("QSpeakers %1 %2 %3 2D").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
    f.replace(' ', '_');
    QString fileName = QFileDialog::getSaveFileName(this, tr("Export for 2D OpenSCAD"), home + QDir::separator() + f + ".scad", tr("OpenSCAD script (*.scad)"));
 
@@ -639,14 +676,14 @@ void MainWindow::on2DScadExport()
     if (fileName.isEmpty())
         return;
 
-   exportScad2D(fileName, currentTabIndex);
+   exportScad2D(fileName, currentTabIndex, margin, thick, saw);
 }
 
 void MainWindow::exportPlot(const QString& outfileName, int tabindex)
 {
     QFile file(outfileName);
     QString f("# QSpeakers plot: ");
-    f += currentSpeaker.getModel() + "\n";
+    f += currentSpeaker.getVendor() + " " + currentSpeaker.getModel() + "\n";
     f += "# freq., dB.\n";
 
     QLineSeries* series;
@@ -682,23 +719,19 @@ void MainWindow::exportPlot(const QString& outfileName, int tabindex)
     file.close();
 }
 
-/* FIXME: should be taken from a popup before to export */
-#define MARGIN 50 /* mm */
-#define WOODTHICK 20 /* mm */
-#define SAWTHICK 1 /* mm */
-
-void MainWindow::exportScad(const QString& scad, const QString &outfileName, int tabindex)
+void MainWindow::exportScad(const QString& scad, const QString &outfileName, int tabindex, qreal margin, qreal thick, qreal saw)
 {
     QFile templ(scad);
     templ.open(QIODevice::ReadOnly);
     QString s = templ.readAll();
 
+    s.replace("__VENDOR__", currentSpeaker.getVendor());
     s.replace("__MODEL__", currentSpeaker.getModel());
     s.replace("__NUMBER__", QString::number(currentSpeakerNumber));
-    s.replace("__MARGIN__", QString::number(MARGIN));
+    s.replace("__MARGIN__", QString::number(margin));
     s.replace("__DIAMETER__", QString::number(currentSpeaker.getDia() * 1000)); /* mm */
-    s.replace("__WOODTHICK__", QString::number(WOODTHICK));
-    s.replace("__SAWTHICK__", QString::number(SAWTHICK));
+    s.replace("__WOODTHICK__", QString::number(thick));
+    s.replace("__SAWTHICK__", QString::number(saw));
     if (tabindex == 0) {
         s.replace("__SEALEDBOXVOLUME__", QString::number(currentSealedBox.getVolume()));
     } else if (tabindex == 1) {
@@ -763,6 +796,9 @@ void MainWindow::onPropertiesRejected()
 
 void MainWindow::onPropertiesAccepted()
 {
+    if (projectProperties.title != propertiesDialog->getTitle() || projectProperties.note != propertiesDialog->getNote())
+        projectSaved = false;
+
     projectProperties.title = propertiesDialog->getTitle();
     projectProperties.note = propertiesDialog->getNote();
 
@@ -773,7 +809,7 @@ void MainWindow::onPropertiesAccepted()
     propertiesDialog = nullptr;
 }
 
-void MainWindow::exportScad3D(const QString &outfileName, int tabindex)
+void MainWindow::exportScad3D(const QString &outfileName, int tabindex, qreal margin, qreal thick)
 {
     QFile file(outfileName);
     QString scad;
@@ -813,11 +849,11 @@ void MainWindow::exportScad3D(const QString &outfileName, int tabindex)
         return;
     }
 
-    exportScad(scad, outfileName, tabindex);
+    exportScad(scad, outfileName, tabindex, margin, thick, 0);
 }
 
 
-void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
+void MainWindow::exportScad2D(const QString &outfileName, int tabindex, qreal margin, qreal thick, qreal saw)
 {
     QFile file(outfileName);
     QString scad;
@@ -857,7 +893,7 @@ void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
         return;
     }
 
-    exportScad(scad, outfileName, tabindex);
+    exportScad(scad, outfileName, tabindex, margin, thick, saw);
 }
 
 void MainWindow::linkMenus()
@@ -912,7 +948,8 @@ void MainWindow::linkTabs()
     connect(ui->sealedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onSealedVolumeDoubleSpinChanged);
 
     connect(ui->portedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedVolumeDoubleSpinChanged);
-    connect(ui->portedResonancedoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedResonanceDoubleSpinChanged);
+    connect(ui->portedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedResonanceDoubleSpinChanged);
+    connect(ui->portedQualityLossFactorSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onPortedQualityLossFactorSpinBoxChanged);
     connect(ui->portedPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onPortedPortsNumberSpinChanged);
     connect(ui->portedPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedPortDiameterDoubleSpinChanged);
     connect(ui->portedPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onPortedSlotPortActivated);
@@ -921,6 +958,7 @@ void MainWindow::linkTabs()
     connect(ui->bandPassSealedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassSealedVolumeDoubleSpinChanged);
     connect(ui->bandPassPortedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedVolumeDoubleSpinChanged);
     connect(ui->bandPassPortedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedResonanceDoubleSpinChanged);
+    connect(ui->bandPassQualityLossFactorSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassQualityLossFactorSpinBoxChanged);
     connect(ui->bandPassPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassPortNumSpinChanged);
     connect(ui->bandPassPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortDiameterDoubleSpinChanged);
     connect(ui->bandpassPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onBandPassSlotPortActivated);
@@ -930,6 +968,7 @@ void MainWindow::linkTabs()
 void MainWindow::linkInternals()
 {
     connect(this, &MainWindow::currentSpeakerChanged, this, &MainWindow::onCurrentSpeakerChanged);
+
     connect(this, &MainWindow::currentSealedBoxChanged, this, &MainWindow::onCurrentSealedBoxChanged);
     connect(this, &MainWindow::currentPortedBoxChanged, this, &MainWindow::onCurrentPortedBoxChanged);
     connect(this, &MainWindow::currentBandPassBoxChanged, this, &MainWindow::onCurrentBandPassBoxChanged);
@@ -982,7 +1021,8 @@ void MainWindow::unlinkTabs()
     disconnect(ui->sealedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onSealedVolumeDoubleSpinChanged);
 
     disconnect(ui->portedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedVolumeDoubleSpinChanged);
-    disconnect(ui->portedResonancedoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedResonanceDoubleSpinChanged);
+    disconnect(ui->portedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedResonanceDoubleSpinChanged);
+    disconnect(ui->portedQualityLossFactorSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onPortedQualityLossFactorSpinBoxChanged);
     disconnect(ui->portedPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onPortedPortsNumberSpinChanged);
     disconnect(ui->portedPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onPortedPortDiameterDoubleSpinChanged);
     disconnect(ui->portedPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onPortedSlotPortActivated);
@@ -991,6 +1031,7 @@ void MainWindow::unlinkTabs()
     disconnect(ui->bandPassSealedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassSealedVolumeDoubleSpinChanged);
     disconnect(ui->bandPassPortedVolumeDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedVolumeDoubleSpinChanged);
     disconnect(ui->bandPassPortedResonanceDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortedResonanceDoubleSpinChanged);
+    disconnect(ui->bandPassQualityLossFactorSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassQualityLossFactorSpinBoxChanged);
     disconnect(ui->bandPassPortsNumberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onBandPassPortNumSpinChanged);
     disconnect(ui->bandPassPortDiameterDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &MainWindow::onBandPassPortDiameterDoubleSpinChanged);
     disconnect(ui->bandpassPortSlotWidthButton, &QPushButton::clicked, this, &MainWindow::onBandPassSlotPortActivated);
@@ -1170,7 +1211,9 @@ void MainWindow::onProjectPrint()
 {
     QPrinter printer;
     printer.setCreator("QSpeakers");
-    printer.setDocName("qspeakers_project");
+    printer.setDocName("QSpeakers Project");
+    QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
+    printer.setOutputFileName("QSpeakers_" + currentSpeaker.getVendor() + "_" + currentSpeaker.getModel() + "_" + box + ".pdf");
     printer.setPageOrientation(QPageLayout::Landscape);
     QPrintDialog dialog(&printer, this);
     if (dialog.exec() == QDialog::Accepted) {
@@ -1205,9 +1248,9 @@ void MainWindow::onAboutAbout()
                           "This program simulates common acoustical enclosures "
                           "behaviour to help designing loudspeaker systems.\n\n"
                           "This program is free software, copyright (C) 2014 "
-                          "Benoit Rouits <brouits@free.fr> and released under the "
-                          "GNU General Public Lisence version 3. It is delivered "
-                          "as is in the hope it can be useful, but with NO WARRANTY at all.").arg(VERSION, REVISION));
+                          "Benoît Rouits <brouits@free.fr> and released under the "
+                          "GNU General Public License version 3. It is delivered "
+                          "as is in the hope it can be useful, but with NO WARRANTY AT ALL.").arg(VERSION, REVISION));
 }
 
 void MainWindow::onSearchRequested(const QString& param, double min, double max)
@@ -1337,7 +1380,7 @@ void MainWindow::onVendorChanged(QString vendor)
 
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      tr("Speaker driver %1 is not present in the database. Do you want to insert it before to continue?").arg(notInDbSpeaker->getModel()),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
@@ -1394,7 +1437,7 @@ void MainWindow::onModelChanged(QString model)
 
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      tr("Speaker driver %1 is not present in the database. Do you want to insert it before to continue?").arg(notInDbSpeaker->getModel()),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
@@ -1497,6 +1540,15 @@ void MainWindow::onPortedResonanceDoubleSpinChanged(double val)
     this->commandStack->push(com);
 }
 
+void MainWindow::onPortedQualityLossFactorSpinBoxChanged(int val)
+{
+    PortedQualityCommand* com = new PortedQualityCommand (currentPortedBox.getLossQualityFactor(), val, this);
+    this->commandStack->push(com);
+
+    currentPortedBox.setLossQualityFactor(val);
+    syncUiFromCurrentPortedBox(currentPortedBox);
+}
+
 void MainWindow::changePortedResFreq(double val)
 {
     currentPortedBox.setResFreq(val);
@@ -1504,6 +1556,12 @@ void MainWindow::changePortedResFreq(double val)
     syncUiFromCurrentPortedBox(currentPortedBox);
 }
 
+void MainWindow::changePortedQualityLossFactor(double val)
+{
+    currentPortedBox.setLossQualityFactor(val);
+    syncUiFromCurrentPortedBox(currentPortedBox);
+}
+
 void MainWindow::onPortedPortsNumberSpinChanged(int val)
 {
     PortedPortNumberCommand* com = new PortedPortNumberCommand (currentPortedBox.getPortNum(), val, this);
@@ -1601,6 +1659,12 @@ void MainWindow::onBandPassPortedResonanceDoubleSpinChanged(double val)
     this->commandStack->push(com);
 }
 
+void MainWindow::onBandPassQualityLossFactorSpinBoxChanged(int val)
+{
+    BPQualityCommand *com = new BPQualityCommand(currentBandPassBox.getLossQualityFactor(), val, this);
+    this->commandStack->push(com);
+}
+
 void MainWindow::changeBPPortedResFreq(double val)
 {
     currentBandPassBox.setPortedBoxResFreq(val);
@@ -1608,6 +1672,12 @@ void MainWindow::changeBPPortedResFreq(double val)
     syncUiFromCurrentBandPassBox(currentBandPassBox);
 }
 
+void MainWindow::changeBPQualityLossFactor(double val)
+{
+    currentBandPassBox.setLossQualityFactor(val);
+    syncUiFromCurrentBandPassBox(currentBandPassBox);
+}
+
 void MainWindow::onBandPassPortNumSpinChanged(int val)
 {
     BPPortedPortNumberCommand* com = new BPPortedPortNumberCommand (currentBandPassBox.getPortedBoxPortNum(), val, this);
@@ -1669,3 +1739,4 @@ void MainWindow::onCurrentBandPassBoxChanged(const BandPassBox &box)
 
     syncUiFromCurrentBandPassBox(box);
 }
+// vim:sw=4:ts=4:et
