@@ -5,10 +5,16 @@
 
 #include "portedbox.h"
 
-PortedBox::PortedBox(double volume, double resfreq, unsigned int portnum, double portdiam, double portlen) :
-    box(volume)
+PortedBox::PortedBox(double volume,
+                     double resfreq,
+                     unsigned int portnum,
+                     double portdiam,
+                     double portlen,
+                     double qloss)
+    : box(volume)
 {
     setResFreq(resfreq);
+    qLossFactor = qloss;
     portNum = portnum;
     setPortDiam(portdiam);
     setPortLen(portlen);
@@ -45,6 +51,11 @@ void PortedBox::setResFreq(double value)
     resFreq = double ((int)(value * 100) / 100.0);
 }
 
+void PortedBox::setLossQualityFactor(double newQualityFactor)
+{
+    qLossFactor = newQualityFactor;
+}
+
 void PortedBox::setSlotPortActivated(bool enable)
 {
     slotActivated = enable;
@@ -100,6 +111,11 @@ double PortedBox::getResFreq() const
     return resFreq;
 }
 
+double PortedBox::getLossQualityFactor() const
+{
+    return qLossFactor;
+}
+
 void PortedBox::updatePorts(double sd, double xmax)
 {
     /* compute minimum port diameter and optionaly set it */
@@ -139,6 +155,7 @@ QDomElement PortedBox::toDomElement(QDomDocument& doc) const
 
     e.setAttribute("type", "ported");
     e.setAttribute("res", c.toString(resFreq));
+    e.setAttribute("ql", c.toString(qLossFactor));
 
     QDomElement b = box.toDomElement(doc);
     e.appendChild(b);
@@ -166,7 +183,12 @@ void PortedBox::fromDomElement(const QDomElement &e)
         return;
     }
 
+    bool ok = false;
+
     resFreq = c.toDouble(e.attribute("res"));
+    qLossFactor = c.toDouble(e.attribute("ql"), &ok);
+    if (!ok)
+        qLossFactor = 7.;
 
     QDomElement b = e.elementsByTagName("box").at(0).toElement();
     box.fromDomElement(b);
@@ -192,7 +214,7 @@ void PortedBox::render(QPainter *painter, const QRectF &area) const
 
     painter->drawRoundedRect(area.toRect(), 5, 5);
 
-    params[0] = QObject::tr("Volume: %1 L").arg(QString::number(getBoxVolume(), 'f', 3));
+    params[0] = QObject::tr("Volume: %1 L").arg(QString::number(getBoxVolume(), 'f', 2));
     if (!slotActivated) {
         params[1] = QObject::tr("Port Diameter: %1 cm").arg(QString::number(getPortDiam(), 'f', 1));
     } else {
@@ -208,10 +230,11 @@ void PortedBox::render(QPainter *painter, const QRectF &area) const
 
     for (int i = 0; i < PORTED_PARAMS; i++) {
         QString text = params[i];
-        QRectF where(tab, area.top(), realwidth / PORTED_PARAMS, area.height());
         QTextOption option(Qt::AlignVCenter|Qt::AlignLeft);
+        qreal textwidth = painter->boundingRect(QRect(0, 0, realwidth, 0), text, option).width() + BOX_RENDER_MARGINS;
+        QRectF where(tab, area.top(), qMax(realwidth / PORTED_PARAMS, textwidth), area.height());
         painter->drawText(where, text, option);
-        tab += realwidth / PORTED_PARAMS;
+        tab += where.width();
     }
 
     painter->setFont(orig);
